==> creative_innovative-1.0.0.tar.gz: creative_innovative/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Features
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

Creative & Innovative Theme is Mobile-friendly Drupal 8/9 responsive theme. This
theme features a custom Banner/Slider (Choose one image for banner or more to create slider), Colors, Footercopyright  field, Social Menu Icon, Contact us Information Fields, Arrow up icone position field(Left/Right), responsive layout, multiple column layouts and is highly customizable. It also supports Google fonts, font awesome(version 5), and it is great for any kind of business website.

 Creative & Innovative Theme is developed with all latest technologies Drupal 8/9,
 Bootstrap5, Font Awesome etc.

 * For a full description of the theme, visit the project page:
   https://www.drupal.org/project/creative_innovative

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/creative_innovative


 FEATURES
--------
 * Responsive, Mobile-Friendly Theme
 * Supported Bootstrap5
 * In built Font Awesome5
 * Mobile support (Smartphone, Tablet, Android, iPhone, etc)
 * A total of 10 block regions
 * Custom Banner and Slider background
 * Sticky header
 * Drop Down main menus with toggle menu at mobile.


REQUIREMENTS
------------

This theme requires only Bootstrap5 outside of Drupal core.


INSTALLATION
------------

 * Install the Creative & Innovative theme as you would normally install a
   contributed Drupal theme. Visit https://www.drupal.org/node/1897420 for
   further information.


CONFIGURATION
-------------

Navigate to Administration > Appearance and enable the theme.

Available options in the theme settings:

 * Hide/show banner/slider in front page.
 * Choose One Image for to show Banner on page or choose multiple images to show slider.
 * Hide/show and change copyright text.
 * Hide/show and change Social Media Icon.
 * Hide/show and change Information Field text.
 * Hide/show bottom to top scroll or choose to align Left or right side of the site.
 * Color option for body, Navbar(Header), Footer.
 * Choose wisely the color combination for page to look attractive.

MAINTAINERS
-----------

 * Ashutosh Ahirwal (ashutoshahirwal) - https://www.drupal.org/u/ashutosh-ahirwal

==> creative_innovative-1.2.3.tar.gz: creative_innovative/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Features
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

Creative & Innovative Theme is Mobile-friendly Drupal 8/9 responsive theme. 
This theme features a custom Banner/Slider (Choose one image for banner or more to create slider), Colors, Footercopyright  field, Social Menu Icon, Contact us Information Fields, Arrow up icone position field(Left/Right), responsive layout, multiple column layouts and is highly customizable.
It also supports Google fonts, font awesome(version 5), and it is great for any kind of business website.

 Creative_Innovative Theme is developed with all latest technologies Drupal 8/9,
 Bootstrap5, Font Awesome etc.

 * For a full description of the theme, visit the project page:
   https://www.drupal.org/project/creative_innovative

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/creative_innovative


 FEATURES
--------
 * Responsive, Mobile-Friendly Theme
 * Supported Bootstrap5
 * In built Font Awesome5
 * Mobile support (Smartphone, Tablet, Android, iPhone, etc)
 * A total of 10 block regions
 * Custom Banner and Slider background
 * Sticky header
 * Drop Down main menus with toggle menu at mobile.


REQUIREMENTS
------------

This theme requires only Bootstrap5 outside of Drupal core.


INSTALLATION
------------

 * Install the Creative & Innovative theme as you would normally install a
   contributed Drupal theme. Visit https://www.drupal.org/node/1897420 for
   further information.


CONFIGURATION
-------------

Navigate to Administration > Appearance and enable the theme.

Available options in the theme settings:

 * Hide/show banner/slider in front page.
 * Choose One Image to show Banner or choose multiple images to show slider.
 * Hide/show and change copyright text.
 * Hide/show and change Social Media Icon.
 * Hide/show and change Information Field text.
 * Hide/show bottom top scroll or choose to align Left/right side of the site.
 * Color option for body, Navbar(Header), Footer.
 * Choose wisely the color combination for page to look attractive.

MAINTAINERS
-----------

 * Ashutosh Ahirwal (ashutoshahirwal) - https://www.drupal.org/u/ashutosh-ahirwal
